<template>
  <el-popover
    class='pop'
    :disabled="item.disabled"
    :offset="250"
    placement="right"
    popper-class="no-padding-popover"
    width="500"
    trigger="click">
    <div class="container">
      <flexbox class="header">
        <div class="name">客户</div>
        <!--<div class="detail"></div>-->
        <img
          class="close"
          src="@/assets/img/task_close.png"
          @click="hidenView" >
      </flexbox>
      <flexbox class="content">
        <div class="cropper-box">
          <span class='searchTitle'>查找内容：</span>
          <el-input class='searchInput' v-model='popSearch' placeholder='请输入客户名称'></el-input>
          <el-button  type="primary" class='searchBtn' @click='getCustomerTable'>立即查找</el-button>
        </div>
      </flexbox>
      <el-table
        v-loading="loading"
        :data="popData"
        :cell-style="popCellStyle"
        :header-cell-style="headerCellStyle"
        height="250"
        style="margin-right:3px;"
        highlight-current-row
        @row-click="handlePopRowClick">
        <el-table-column
          v-for="(item, index) in popFieldList"
          :key="index"
          :prop="item.field"
          :label="item.value"
          align="center"
          header-align="center"
          show-overflow-tooltip/>
      </el-table>
      <div class="p-contianer">
        <el-pagination
          :current-page="currentPopPage"
          :page-sizes="pagePopSizes"
          :page-size.sync="pagePopSize"
          :total="totalPop"
          class="p-bar"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="handlePopSizeChange"
          @current-change="handlePopCurrentChange"/>
      </div>
    </div>
    <el-input slot="reference" :disabled='true' v-model='customerChosed' placeholder='请点击选择客户'></el-input>
  </el-popover>
</template>
<script type="text/javascript">
import { GetPersonalCustomerPageList } from '@/api/customermanagement/customerManage'
export default {
  name: 'XhRelativeInput', // 新建 XhRelativeInput
  components: {},
  props: {
    item: {
      type: Object,
      default: () => {
        return {}
      }
    },
    customerId: {
      type: String,
      default: () => {
        return ''
      }
    }
  },
  data () {
    return {
      loading: false,
      popData: [],
      currentPopPage: 1,
      pagePopSize: 15,
      pagePopSizes: [15, 30, 60, 100],
      customerChosed: '',
      popSearch: '',
      totalPop: 0
    }
  },
  computed: {
    popFieldList () {
      if (this.item && this.item.field === 'CustomerId') {
        return [
          { field: 'CustomerNumber', value: '客户编号', width: '20' },
          { field: 'CustomerName', value: '客户名称', width: '20' },
          { field: 'Contacter', value: '联系人', width: '20' },
          { field: 'ContactMobile', value: '联系人方式', width: '30' },
          { field: 'CustomerStatus', value: '客户业务状态', width: '10' },
          { field: 'CustomerSource', value: '客户来源', width: '10' },
          { field: 'CustomerType', value: '客户大类型', width: '10' },
          { field: 'CostomerCategory', value: '客户类别', width: '10' },
          { field: 'Industry', value: '所属行业', width: '12' },
          { field: 'ProvinceCode', value: '省编码', width: '10' },
          { field: 'CityCode', value: '市编码', width: '10' },
          { field: 'SaleOwerId', value: '销售员', width: '10' },
          { field: 'SaleName', value: '销售员姓名', width: '10' },
          { field: 'CreateTime', value: '创建时间', width: '10' },
          { field: 'NextFollowTime', value: '最新跟进时间', width: '10' }
        ]
      } else {
        return []
      }
    }
  },
  watch: {
  },
  mounted () {
    console.log(1111111, this.item)
    if (this.item && this.item.field === 'CustomerId') {
      this.customerChosed = this.item.chosedCusName ? this.item.chosedCusName : ''
      this.getCustomerTable()
    }
  },
  methods: {
    /** 通过回调控制style */
    popCellStyle ({ row, column, rowIndex, columnIndex }) {
      return { fontSize: '12px', textAlign: 'center', cursor: 'pointer' }
    },
    headerCellStyle ({ row, column, rowIndex, columnIndex }) {
      return { fontSize: '12px', textAlign: 'center' }
    },
    handlePopSizeChange (newSize) {
      this.pagePopSizes = newSize
      this.getCustomerTable()
    },
    handlePopCurrentChange (newPage) {
      this.currentPopPage = newPage
      this.getCustomerTable()
    },
    getCustomerTable () {
      let params = {
        Name: this.popSearch,
        PageIndex: this.currentPopPage,
        PageSize: this.pagePopSize
      }
      if (this.item && this.item.field === 'CustomerId') {
        GetPersonalCustomerPageList(params).then(res => {
          if (res.data.ErrorCode === 200 && res.data.Result !== 0) {
            this.popData = res.data.Result.List || []
            this.totalPop = res.data.Result.Count
          } else {
            this.$message.error(res.data.Message)
            this.loading = false
          }
        })
      }
    },
    hidenView () {
      document.querySelector('#app').click()
      this.$emit('close', this.$el, this.data)
    },
    // 当某一行被点击时会触发该事件
    handlePopRowClick (row, column, event) {
      this.$emit('value-change', {index: this.item.field,
        value: row.Id,
        name: row.CustomerName})
      this.customerChosed = row.CustomerName
      console.log(this.customerChosed)
      this.hidenView()
    }

  }
}
</script>
<style lang="scss" scoped>
.container {
  position: relative;
}

.header {
  height: 40px;
  padding: 0 10px;
  flex-shrink: 0;
  .name {
    font-size: 13px;
    padding: 0 10px;
    color: #333;
  }
  .detail {
    font-size: 12px;
    padding: 0 10px;
    color: #aaaaaa;
    border-left: 1px solid #aaaaaa;
  }
  .close {
    position: absolute;
    width: 40px;
    height: 40px;
    top: 0;
    right: 10px;
    padding: 10px;
  }
}
.content{
  .cropper-box{
    display:flex;
    flex-direction: row;
    align-items: center;
    padding: 0 20px;
    .searchTitle{
      font-size: 14px;
      width: 124px;
      color: #333;
    }
    .searchInput{
      margin-right: 20px;
    }
  }
}
.p-contianer .p-bar{
  margin: 5px 0 0 14px;
}
.pop /deep/ .el-input.is-disabled .el-input__inner{
  cursor: pointer;
}
</style>
